# aws-eden-core [![PyPi version](https://img.shields.io/pypi/v/aws-eden-core.svg)](https://pypi.python.org/pypi/aws-eden-core/) ![](https://img.shields.io/badge/python-3.6+-blue.svg) ![t](https://img.shields.io/badge/status-beta-orange.svg) 

ECS Dynamic Environment Manager (eden) core package

Provides AWS API access methods, validators and create/delete environment capabilities. Used by [aws-eden-cli](https://github.com/baikonur-oss/aws-eden-cli) and [eden API](https://github.com/baikonur-oss/terraform-aws-lambda-eden-api). 

Works only with Python 3.6+.
